Enum polkadot_runtime_common::auctions::pallet::Call [−][src]
pub enum Call<T: Config> {
new_auction {
duration: T::BlockNumber,
lease_period_index: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod,
},
bid {
para: ParaId,
auction_index: AuctionIndex,
first_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod,
last_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod,
amount: <<<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::Currency as Currency<<T as Config>::AccountId>>::Balance,
},
cancel_auction {},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Create a new auction.
This can only happen when there isn’t already an auction in progress and may only be
called by the root origin. Accepts the duration of this auction and the
lease_period_index of the initial lease period of the four that are to be auctioned.
Fields of new_auction
duration: T::BlockNumberlease_period_index: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriodMake a new bid from an account (including a parachain account) for deploying a new parachain.
Multiple simultaneous bids from the same bidder are allowed only as long as all active bids overlap each other (i.e. are mutually exclusive). Bids cannot be redacted.
subis the sub-bidder ID, allowing for multiple competing bids to be made by (and funded by) the same account.auction_indexis the index of the auction to bid on. Should just be the present value ofAuctionCounter.first_slotis the first lease period index of the range to bid on. This is the absolute lease period index value, not an auction-specific offset.last_slotis the last lease period index of the range to bid on. This is the absolute lease period index value, not an auction-specific offset.amountis the amount to bid to be held as deposit for the parachain should the bid win. This amount is held throughout the range.
Fields of bid
para: ParaIdauction_index: AuctionIndexfirst_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriodlast_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriodamount: <<<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::Currency as Currency<<T as Config>::AccountId>>::BalanceCancel an in-progress auction.
Can only be called by Root origin.
Fields of cancel_auction
Implementations
pub fn new_call_variant_new_auction(
duration: T::BlockNumber,
lease_period_index: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod
) -> Self
pub fn new_call_variant_new_auction(
duration: T::BlockNumber,
lease_period_index: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod
) -> Self
Create a call with the variant new_auction.
pub fn new_call_variant_bid(
para: ParaId,
auction_index: AuctionIndex,
first_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod,
last_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod,
amount: <<<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::Currency as Currency<<T as Config>::AccountId>>::Balance
) -> Self
pub fn new_call_variant_bid(
para: ParaId,
auction_index: AuctionIndex,
first_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod,
last_slot: <<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::LeasePeriod,
amount: <<<T as Config>::Leaser as Leaser<<T as Config>::BlockNumber>>::Currency as Currency<<T as Config>::AccountId>>::Balance
) -> Self
Create a call with the variant bid.
Create a call with the variant cancel_auction.