Struct polkadot_runtime_common::paras_registrar::pallet::Pallet [−][src]
pub struct Pallet<T>(_);Expand description
The pallet implementing the on-chain logic.
Implementations
pub fn register(
origin: OriginFor<T>,
id: ParaId,
genesis_head: HeadData,
validation_code: ValidationCode
) -> DispatchResult
pub fn register(
origin: OriginFor<T>,
id: ParaId,
genesis_head: HeadData,
validation_code: ValidationCode
) -> DispatchResult
Register head data and validation code for a reserved Para Id.
Arguments
origin: Must be called by aSignedorigin.id: The para ID. Must be owned/managed by theoriginsigning account.genesis_head: The genesis head data of the parachain/thread.validation_code: The initial validation code of the parachain/thread.
Deposits/Fees
The origin signed account must reserve a corresponding deposit for the registration. Anything already reserved previously for this para ID is accounted for.
Events
The Registered event is emitted in case of success.
pub fn force_register(
origin: OriginFor<T>,
who: T::AccountId,
deposit: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
id: ParaId,
genesis_head: HeadData,
validation_code: ValidationCode
) -> DispatchResult
pub fn force_register(
origin: OriginFor<T>,
who: T::AccountId,
deposit: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
id: ParaId,
genesis_head: HeadData,
validation_code: ValidationCode
) -> DispatchResult
Force the registration of a Para Id on the relay chain.
This function must be called by a Root origin.
The deposit taken can be specified for this registration. Any ParaId
can be registered, including sub-1000 IDs which are System Parachains.
Deregister a Para Id, freeing all data and returning any deposit.
The caller must be Root, the para owner, or the para itself. The para must be a parathread.
Swap a parachain with another parachain or parathread.
The origin must be Root, the para owner, or the para itself.
The swap will happen only if there is already an opposite swap pending. If there is not, the swap will be stored in the pending swaps map, ready for a later confirmatory swap.
The ParaIds remain mapped to the same head data and code so external code can rely on
ParaId to be a long-term identifier of a notional “parachain”. However, their
scheduling info (i.e. whether they’re a parathread or parachain), auction information
and the auction deposit are switched.
Remove a manager lock from a para. This will allow the manager of a previously locked para to deregister or swap a para without using governance.
Can only be called by the Root origin.
Reserve a Para Id on the relay chain.
This function will reserve a new Para Id to be owned/managed by the origin account.
The origin account is able to register head data and validation code using register to create
a parathread. Using the Slots pallet, a parathread can then be upgraded to get a parachain slot.
Arguments
origin: Must be called by aSignedorigin. Becomes the manager/owner of the new para ID.
Deposits/Fees
The origin must reserve a deposit of ParaDeposit for the registration.
Events
The Reserved event is emitted in case of success, which provides the ID reserved for use.