Enum polkadot_runtime_common::purchase::pallet::Call [−][src]
pub enum Call<T: Config> {
create_account {
who: T::AccountId,
signature: Vec<u8>,
},
update_validity_status {
who: T::AccountId,
validity: AccountValidity,
},
update_balance {
who: T::AccountId,
free_balance: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
locked_balance: <<T as Config>::Currency as Currency<<T as Config>::AccountId>>::Balance,
vat: Permill,
},
payout {
who: T::AccountId,
},
set_payment_account {
who: T::AccountId,
},
set_statement {
statement: Vec<u8>,
},
set_unlock_block {
unlock_block: T::BlockNumber,
},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Create a new account. Proof of existence through a valid signed message.
We check that the account does not exist at this stage.
Origin must match the ValidityOrigin.
Update the validity status of an existing account. If set to completed, the account will no longer be able to continue through the crowdfund process.
We check that the account exists at this stage, but has not completed the process.
Origin must match the ValidityOrigin.
Fields of update_validity_status
who: T::AccountIdvalidity: AccountValidityUpdate the balance of a valid account.
We check that the account is valid for a balance transfer at this point.
Origin must match the ValidityOrigin.
Fields of update_balance
Pay the user and complete the purchase process.
We reverify all assumptions about the state of an account, and complete the process.
Origin must match the configured PaymentAccount.
Fields of payout
who: T::AccountIdSet the account that will be used to payout users in the DOT purchase process.
Origin must match the ConfigurationOrigin
Fields of set_payment_account
who: T::AccountIdSet the statement that must be signed for a user to participate on the DOT sale.
Origin must match the ConfigurationOrigin
Set the block where locked DOTs will become unlocked.
Origin must match the ConfigurationOrigin
Fields of set_unlock_block
unlock_block: T::BlockNumberImplementations
Create a call with the variant create_account.
pub fn new_call_variant_update_validity_status(
who: T::AccountId,
validity: AccountValidity
) -> Self
pub fn new_call_variant_update_validity_status(
who: T::AccountId,
validity: AccountValidity
) -> Self
Create a call with the variant update_validity_status.
Create a call with the variant update_balance.
Create a call with the variant payout.
Create a call with the variant set_payment_account.
Create a call with the variant set_statement.
Create a call with the variant set_unlock_block.