Enum polkadot_runtime_common::traits::AuctionStatus [−][src]
pub enum AuctionStatus<BlockNumber> {
NotStarted,
StartingPeriod,
EndingPeriod(BlockNumber, BlockNumber),
VrfDelay(BlockNumber),
}Expand description
An enum which tracks the status of the auction system, and which phase it is in.
Variants
An auction has not started yet.
We are in the starting period of the auction, collecting initial bids.
We are in the ending period of the auction, where we are taking snapshots of the winning
bids. This state supports “sampling”, where we may only take a snapshot every N blocks.
In this case, the first number is the current sample number, and the second number
is the sub-sample. i.e. for sampling every 20 blocks, the 25th block in the ending period
will be EndingPeriod(1, 5).
We have completed the bidding process and are waiting for the VRF to return some acceptable randomness to select the winner. The number represents how many blocks we have been waiting.
Implementations
Returns true if the auction is in any state other than NotStarted.
Return true if the auction is in the starting period.
Returns Some(sample, sub_sample) if the auction is in the EndingPeriod,
otherwise returns None.